==> zio-aws-rekognition_2.12-5.17.158.4-sources.jar: zio/aws/rekognition/model/Gender.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.Percent
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Gender(
    value: Option[zio.aws.rekognition.model.GenderType] = None,
    confidence: Option[Percent] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Gender = {
    import Gender.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Gender
      .builder()
      .optionallyWith(value.map(value => value.unwrap))(_.value)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Gender.ReadOnly =
    zio.aws.rekognition.model.Gender.wrap(buildAwsValue())
}
object Gender {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Gender
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Gender = zio.aws.rekognition.model
      .Gender(value.map(value => value), confidence.map(value => value))
    def value: Option[zio.aws.rekognition.model.GenderType]
    def confidence: Option[Percent]
    def getValue: ZIO[Any, AwsError, zio.aws.rekognition.model.GenderType] =
      AwsError.unwrapOptionField("value", value)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Gender
  ) extends zio.aws.rekognition.model.Gender.ReadOnly {
    override val value: Option[zio.aws.rekognition.model.GenderType] = scala
      .Option(impl.value())
      .map(value => zio.aws.rekognition.model.GenderType.wrap(value))
    override val confidence: Option[Percent] = scala
      .Option(impl.confidence())
      .map(value => zio.aws.rekognition.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Gender
  ): zio.aws.rekognition.model.Gender.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.19.7.5-sources.jar: zio/aws/rekognition/model/Gender.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.Percent
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Gender(
    value: Optional[zio.aws.rekognition.model.GenderType] = Optional.Absent,
    confidence: Optional[Percent] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Gender = {
    import Gender.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Gender
      .builder()
      .optionallyWith(value.map(value => value.unwrap))(_.value)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Gender.ReadOnly =
    zio.aws.rekognition.model.Gender.wrap(buildAwsValue())
}
object Gender {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Gender
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Gender = zio.aws.rekognition.model
      .Gender(value.map(value => value), confidence.map(value => value))
    def value: Optional[zio.aws.rekognition.model.GenderType]
    def confidence: Optional[Percent]
    def getValue: ZIO[Any, AwsError, zio.aws.rekognition.model.GenderType] =
      AwsError.unwrapOptionField("value", value)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Gender
  ) extends zio.aws.rekognition.model.Gender.ReadOnly {
    override val value: Optional[zio.aws.rekognition.model.GenderType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.value())
        .map(value => zio.aws.rekognition.model.GenderType.wrap(value))
    override val confidence: Optional[Percent] = zio.aws.core.internal
      .optionalFromNullable(impl.confidence())
      .map(value => zio.aws.rekognition.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Gender
  ): zio.aws.rekognition.model.Gender.ReadOnly = new Wrapper(impl)
}
